/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "ColorList.h"

#include "ContextMenu.h"
#include "GridLayout.h"
#include "Debug.h"
#include "BaseIconNames.h"
#include "IconEngine.h"
#include "QtUtil.h"
#include "QuestionDialog.h"
#include "Util.h"

//____________________________________________________________
ColorList::ColorList( QWidget* parent ):
    QGroupBox( "Saved Colors", parent )
{

    Debug::Throw( "ColorList::ColorList.\n" );

    _installActions();

    QVBoxLayout* layout = new QVBoxLayout( this );
    setLayout( layout );

    layout->addWidget( list_ = new TreeView( this ) );
    list_->setDragEnabled( true );
    list_->setModel( &model_ );
    list_->setSelectionMode( QAbstractItemView::ContiguousSelection );
    ( new ContextMenu( list_ ) )->addAction( removeAction_ );
    connect( list_->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(_updateActions()) );
    _updateActions();

}

//____________________________________________________________
void ColorList::add( const Base::Color& color, bool select )
{

    Debug::Throw( "ColorList::add.\n" );
    model_.add( color );

    // retrieve index
    if( select )
    {
        QModelIndex selectedIndex( model_.index( color ) );
        list_->selectionModel()->select( selectedIndex,  QItemSelectionModel::Clear|QItemSelectionModel::Select|QItemSelectionModel::Rows );
    }

}

//_____________________________________________________________
void ColorList::_remove()
{
    Debug::Throw( "ColorList::_remove\n" );

    // retrieve selected indexes in list
    QModelIndexList selectedIndexes( list_->selectionModel()->selectedRows() );
    if( selectedIndexes.empty() || !QuestionDialog( this, tr( "Remove selected colors from list ?" ) ).exec() ) return;

    ColorModel::List colors( model_.get( selectedIndexes ) );
    for( const auto& color:colors )
    { model_.remove( color ); }

    _updateActions();

}

//_________________________________________________________________________
void ColorList::_updateActions()
{
    Debug::Throw( "ColorList::_updateActions.\n" );
    bool hasSelection( !list_->selectionModel()->selectedRows().empty() );
    removeAction_->setEnabled( hasSelection );
}

//_________________________________________________________________________
void ColorList::_installActions()
{
    Debug::Throw( "ColorList::_installActions.\n" );

    // actions
    addAction( removeAction_ = new QAction( IconEngine::get( IconNames::Remove ), tr( "Remove" ), this ) );
    removeAction_->setToolTip( tr( "Remove selected colors" ) );
    removeAction_->setShortcut( QKeySequence::Delete );
    connect( removeAction_, SIGNAL(triggered()), SLOT(_remove()) );

}
