#ifndef ColorModel_h
#define ColorModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Color.h"
#include "Counter.h"
#include "ListModel.h"

#include <QMap>
#include <QIcon>
#include <QMimeData>

#include <array>

//* Color model. Stores Color information for display in lists
class ColorModel : public ListModel<Base::Color>, private Base::Counter<ColorModel>
{

    Q_OBJECT

    public:

    //* constructor
    explicit ColorModel( QObject *parent = nullptr ):
        ListModel<Base::Color>( parent ),
        Counter( "ColorModel" )
    {}

    //* column type enumeration
    enum { nColumns = 1 };

    //*@name methods reimplemented from base class
    //@{

    //* flags
    Qt::ItemFlags flags( const QModelIndex& ) const override;

    // return job for a given index
    QVariant data( const QModelIndex&, int ) const override;

    //* header data
    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

    //* number of columns for a given index
    int columnCount( const QModelIndex& = QModelIndex() ) const override
    { return nColumns; }

    //* mime data
    QMimeData* mimeData( const QModelIndexList& ) const override;

    //@}

    protected:

    //* sort
    void _sort( int, Qt::SortOrder ) override;

    private:

    //* used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //* constructor
        explicit SortFTor( int type, Qt::SortOrder order ):
            ItemModel::SortFTor( type, order )
            {}

        //* prediction
        bool operator() ( Base::Color, Base::Color ) const;

    };

    //* icon cache
    using IconCache = QMap<Base::Color, QIcon>;

    //* icon cache
    static IconCache& _icons();

    //* icon matching color
    static QIcon _icon( const Base::Color& );

    //* list column names
    const std::array<QString, nColumns> columnTitles_ = {{ tr( "Color Name" ) }};

};

#endif
